StereoMode

Enum StereoMode 

#[non_exhaustive]
pub enum StereoMode { None, FieldSequentialRightFirst, FieldSequentialLeftFirst, TwoWayInterleavedRightEven, TwoWayInterleavedLeftEven, FourWayInterleaved, SideBySideInterleaved, }
Stereo viewing support decoded from DTD byte 17 bits 6, 5, and 0.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

Normal display; no stereo (bits 6–5 = 0b00; bit 0 is don’t-care).



FieldSequentialRightFirst

Field-sequential stereo, right image when stereo sync = 1 (bits 6–5 = 0b01, bit 0 = 0).



FieldSequentialLeftFirst

Field-sequential stereo, left image when stereo sync = 1 (bits 6–5 = 0b10, bit 0 = 0).



TwoWayInterleavedRightEven

2-way interleaved stereo, right image on even lines (bits 6–5 = 0b01, bit 0 = 1).



TwoWayInterleavedLeftEven

2-way interleaved stereo, left image on even lines (bits 6–5 = 0b10, bit 0 = 1).



FourWayInterleaved

4-way interleaved stereo (bits 6–5 = 0b11, bit 0 = 0).



SideBySideInterleaved

Side-by-side interleaved stereo (bits 6–5 = 0b11, bit 0 = 1).