TypeIxStereoMode

Enum TypeIxStereoMode 

#[non_exhaustive]
pub enum TypeIxStereoMode { Mono, Stereo, MonoOrStereoByUser, Reserved, }
Stereo timing mode decoded from Type V (0x11) and Type IX (0x24) descriptor byte 0 bits 6:5. Indicates whether the timing is for a mono display, stereo-only, or user-selectable.

This is distinct from StereoMode, which describes the specific stereo viewing method decoded from a Detailed Timing Descriptor.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Mono

Mono timing (bits 6:5 = 0b00).



Stereo

3D stereo timing (bits 6:5 = 0b01).



MonoOrStereoByUser

Mono or 3D stereo depending on user action (bits 6:5 = 0b10).



Reserved

Reserved (bits 6:5 = 0b11).