RoomConfigurationBlock

Struct RoomConfigurationBlock 

#[non_exhaustive]
pub struct RoomConfigurationBlock { pub speaker_count: u8, pub has_speaker_locations: bool, }
Decoded Room Configuration Data Block (extended tag 0x13).

Describes the number of loudspeakers in the listening room and whether individual speaker locations are provided in an accompanying Speaker Location Data Block (extended tag 0x14).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
speaker_count: u8

Number of loudspeakers in the room (bits 4:0). 0 means not specified.

has_speaker_locations: bool

If true, individual speaker location entries are present in an accompanying Speaker Location Data Block (extended tag 0x14).

Implementations

Source

impl RoomConfigurationBlock

pub fn new(speaker_count: u8, has_speaker_locations: bool) -> Self

Constructs a RoomConfigurationBlock.