pub struct DisplayFeatureFlags(/* private fields */);Expand description
Boolean capability flags from EDID base block byte 0x18 (Display Feature Support).
Bits 4–3 of this byte encode a color type / supported encoding field whose meaning differs for digital and analog displays. That field is not represented here — it requires a dedicated enum and will be added alongside color encoding support.
| Bit | Mask | Meaning |
|---|---|---|
| 7 | 0x80 | DPMS standby supported |
| 6 | 0x40 | DPMS suspend supported |
| 5 | 0x20 | DPMS active-off supported |
| 2 | 0x04 | sRGB is the default color space |
| 1 | 0x02 | Preferred timing includes native pixel format and rate |
| 0 | 0x01 | Continuous timings supported (GTF or CVT, EDID 1.4+) |
Implementations
Sourceimpl DisplayFeatureFlags
impl DisplayFeatureFlags
Sourcepub const DPMS_STANDBY: Self
pub const DPMS_STANDBY: Self
DPMS standby mode is supported.
Sourcepub const DPMS_SUSPEND: Self
pub const DPMS_SUSPEND: Self
DPMS suspend mode is supported.
Sourcepub const DPMS_ACTIVE_OFF: Self
pub const DPMS_ACTIVE_OFF: Self
DPMS active-off mode is supported.
Sourcepub const PREFERRED_TIMING: Self
pub const PREFERRED_TIMING: Self
The preferred timing mode (first DTD) includes the native pixel format and preferred refresh rate.
Sourcepub const CONTINUOUS_TIMINGS: Self
pub const CONTINUOUS_TIMINGS: Self
Continuous timings are supported via GTF or CVT (EDID 1.4+).
Sourceimpl DisplayFeatureFlags
impl DisplayFeatureFlags
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl DisplayFeatureFlags
impl DisplayFeatureFlags
Sourcepub const fn iter(&self) -> Iter<DisplayFeatureFlags>
pub const fn iter(&self) -> Iter<DisplayFeatureFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DisplayFeatureFlags>
pub const fn iter_names(&self) -> IterNames<DisplayFeatureFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.