#[non_exhaustive]pub enum AnalogSyncLevel {
V700_300,
V714_286,
V1000_400,
V700_0,
}Expand description
Video white and sync levels for an analog display, decoded from EDID base block
byte 0x14 bits 6–5.
Specifies the signal voltage levels used for video white and sync, relative to blank.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
V700_300
0.700 V video / 0.300 V sync / 1.000 V total (most common).
V714_286
0.714 V video / 0.286 V sync / 1.000 V total (EGA/CGA-compatible).
V1000_400
1.000 V video / 0.400 V sync / 1.400 V total.
V700_0
0.700 V video / 0.000 V sync / 0.700 V total.