Module panel

Module panel 

Panel hardware characteristic types.

Structs

DisplayIdInterface
Display interface capabilities, decoded from the Display Interface Data Block (DisplayID 1.x 0x0F).
DisplayIdStereoInterface
Stereo display interface parameters, decoded from the Stereo Display Interface Data Block (DisplayID 1.x 0x10).
DisplayIdTiledTopology
Tiled display topology, decoded from the Tiled Display Topology Data Block (DisplayID 1.x 0x12).
PowerSequencing
Panel interface power sequencing timing parameters, decoded from the Interface Power Sequencing Block (DisplayID 1.x 0x0D).
TileBezelInfo
Bezel sizes around a single tile, decoded from the optional bezel bytes of the Tiled Display Topology Data Block (0x12) when the has_bezel_info flag is set.

Enums

BacklightType
Backlight type, decoded from Display Device Data Block (0x0C) byte 1 bits 5:4.
DisplayInterfaceType
Physical interface standard type, decoded from Display Interface Data Block (0x0F) byte 0 bits 3:0.
DisplayTechnology
Display technology type, decoded from Display Device Data Block (0x0C) byte 0 bits 7:4.
InterfaceContentProtection
Content protection mechanism supported on the display interface, decoded from Display Interface Data Block (0x0F) byte 6 bits 1:0.
OperatingMode
Panel operating mode, decoded from Display Device Data Block (0x0C) byte 1 bits 3:0.
PhysicalOrientation
Physical mounting orientation of the panel, decoded from Display Device Data Block (0x0C) byte 7 bits 1:0.
RotationCapability
Rotation capability, decoded from Display Device Data Block (0x0C) byte 7 bits 3:2.
ScanDirection
Scan direction of the fast (horizontal) scan relative to H-sync, decoded from Display Device Data Block (0x0C) byte 7 bits 7:6.
StereoSyncInterface
Physical interface used to deliver stereo synchronization to the glasses, decoded from Stereo Display Interface Data Block (0x10) byte 1.
StereoViewingMode
Stereo content format, decoded from Stereo Display Interface Data Block (0x10) byte 0 bits 3:0.
SubpixelLayout
Sub-pixel layout, decoded from Display Device Data Block (0x0C) byte 8.
TileTopologyBehavior
Behavior when one or more tiles are missing from a tiled display, decoded from Tiled Display Topology Data Block (0x12) byte 0 bits 5:4.
ZeroPixelLocation
Location of the zero pixel (the upper-left pixel in the framebuffer), decoded from Display Device Data Block (0x0C) byte 7 bits 5:4.