#[non_exhaustive]pub enum StereoSyncInterface {
DisplayConnector,
VesaDin,
Infrared,
RadioFrequency,
Reserved(u8),
}Expand description
Physical interface used to deliver stereo synchronization to the glasses, decoded from Stereo Display Interface Data Block (0x10) byte 1.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DisplayConnector
Sync delivered via the display’s own video connector — no dedicated stereo port (0).
VesaDin
VESA 3-pin DIN stereo connector (1).
Infrared
Infrared (IR) wireless sync (2).
RadioFrequency
Radio frequency (RF) wireless sync (3).
Reserved(u8)
Reserved or unrecognized value (4–255).
Implementations