#[non_exhaustive]pub enum TileTopologyBehavior {
Undefined,
RequireAllTiles,
ScaleWhenMissing,
Reserved(u8),
}Expand description
Behavior when one or more tiles are missing from a tiled display, decoded from Tiled Display Topology Data Block (0x12) byte 0 bits 5:4.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Undefined
Behavior is undefined (0).
RequireAllTiles
No image is shown until all tiles are present and operational (1).
ScaleWhenMissing
The image is scaled to fit whatever tiles are currently present (2).
Reserved(u8)
Reserved or unrecognized value (3).
Implementations