Module resolved

Module resolved 

Resolved display configuration type, for use by drivers and InfoFrame encoders. Resolved display configuration type.

Structs

ResolvedDisplayConfig
A resolved display configuration ready to program into hardware.