Video timing formula types.
Structs
- Computed
Timing - Pixel clock and blanking parameters computed from a CVT formula.
- CvtAspect
Ratios - Aspect ratios supported for CVT-generated timings (byte 14 of a
0xFDdescriptor). - CvtScaling
- Display scaling capabilities reported in byte 16 of a
0xFDCVT descriptor. - CvtSupport
Params - CVT support parameters decoded from a display range limits descriptor (
0xFD). - GtfSecondary
Params - GTF secondary curve parameters decoded from a display range limits descriptor (
0xFD).
Enums
- CvtAspect
Ratio - Preferred aspect ratio for CVT-generated timings, decoded from byte 15 bits 7–5.
- Timing
Formula - Video timing support reported in the display range limits descriptor (
0xFD), byte 10.
Functions
- compute_
type_ ix_ timing - Computes pixel clock and blanking parameters for a DisplayID 2.x Type IX (Formula-Based Timing) descriptor using the named CVT variant.
- pixel_
clock_ khz - Returns the pixel clock in kHz for a
VideoMode.