pub struct VideoMode {
pub width: u16,
pub height: u16,
pub refresh_rate: u8,
pub interlaced: bool,
pub h_front_porch: u16,
pub h_sync_width: u16,
pub v_front_porch: u16,
pub v_sync_width: u16,
pub h_border: u8,
pub v_border: u8,
pub stereo: StereoMode,
pub sync: Option<SyncDefinition>,
}Expand description
A display video mode expressed as resolution, refresh rate, and scan type.
Fields
width: u16Horizontal resolution in pixels.
height: u16Vertical resolution in pixels.
refresh_rate: u8Refresh rate in Hz.
interlaced: booltrue for interlaced modes; false for progressive (the common case).
h_front_porch: u16Horizontal front porch in pixels (0 when not decoded from a DTD).
h_sync_width: u16Horizontal sync pulse width in pixels (0 when not decoded from a DTD).
v_front_porch: u16Vertical front porch in lines (0 when not decoded from a DTD).
v_sync_width: u16Vertical sync pulse width in lines (0 when not decoded from a DTD).
h_border: u8Horizontal border width in pixels on each side of the active area (0 when not from a DTD).
v_border: u8Vertical border height in lines on each side of the active area (0 when not from a DTD).
stereo: StereoModeStereo viewing support (default None for non-DTD modes).
sync: Option<SyncDefinition>Sync signal definition (None for non-DTD modes).