Panel hardware characteristic types.
Structs
- Display
IdInterface - Display interface capabilities, decoded from the Display Interface Data Block
(DisplayID 1.x
0x0F). - Display
IdStereo Interface - Stereo display interface parameters, decoded from the Stereo Display Interface Data Block
(DisplayID 1.x
0x10). - Display
IdTiled Topology - Tiled display topology, decoded from the Tiled Display Topology Data Block
(DisplayID 1.x
0x12). - Power
Sequencing - Panel interface power sequencing timing parameters, decoded from the Interface Power
Sequencing Block (DisplayID 1.x
0x0D). - Tile
Bezel Info - Bezel sizes around a single tile, decoded from the optional bezel bytes of the Tiled
Display Topology Data Block (0x12) when the
has_bezel_infoflag is set.
Enums
- Backlight
Type - Backlight type, decoded from Display Device Data Block (0x0C) byte 1 bits 5:4.
- Display
Interface Type - Physical interface standard type, decoded from Display Interface Data Block (0x0F) byte 0 bits 3:0.
- Display
Technology - Display technology type, decoded from Display Device Data Block (0x0C) byte 0 bits 7:4.
- Interface
Content Protection - Content protection mechanism supported on the display interface, decoded from Display Interface Data Block (0x0F) byte 6 bits 1:0.
- Operating
Mode - Panel operating mode, decoded from Display Device Data Block (0x0C) byte 1 bits 3:0.
- Physical
Orientation - Physical mounting orientation of the panel, decoded from Display Device Data Block (0x0C) byte 7 bits 1:0.
- Rotation
Capability - Rotation capability, decoded from Display Device Data Block (0x0C) byte 7 bits 3:2.
- Scan
Direction - Scan direction of the fast (horizontal) scan relative to H-sync, decoded from Display Device Data Block (0x0C) byte 7 bits 7:6.
- Stereo
Sync Interface - Physical interface used to deliver stereo synchronization to the glasses, decoded from Stereo Display Interface Data Block (0x10) byte 1.
- Stereo
Viewing Mode - Stereo content format, decoded from Stereo Display Interface Data Block (0x10) byte 0 bits 3:0.
- Subpixel
Layout - Sub-pixel layout, decoded from Display Device Data Block (0x0C) byte 8.
- Tile
Topology Behavior - Behavior when one or more tiles are missing from a tiled display, decoded from Tiled Display Topology Data Block (0x12) byte 0 bits 5:4.
- Zero
Pixel Location - Location of the zero pixel (the upper-left pixel in the framebuffer), decoded from Display Device Data Block (0x0C) byte 7 bits 5:4.