#[non_exhaustive]pub enum DisplayTechnology {
Tft,
DstnStn,
TftIps,
TftMva,
Crt,
Pdp,
Oled,
El,
FedSed,
Lcos,
Unknown(u8),
}Expand description
Display technology type, decoded from Display Device Data Block (0x0C) byte 0 bits 7:4.
Identifies the physical display technology used by an embedded panel.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Tft
Thin-film transistor LCD, unspecified sub-type (0).
DstnStn
DSTN or STN (dual-scan or super-twisted nematic LCD) (1).
TftIps
TFT-IPS or super-TFT (in-plane switching) (2).
TftMva
TFT-MVA or TFT-PVA (multi-domain / patterned vertical alignment) (3).
Crt
CRT (cathode ray tube) (4).
Pdp
PDP (plasma display panel) (5).
Oled
OLED or ELED (organic light emitting) (6).
El
EL (electroluminescent) (7).
FedSed
FED or SED (field emission / surface-conduction electron emission) (8).
Lcos
LCoS (liquid crystal on silicon) (9).
Unknown(u8)
Reserved or undefined value (10–15).
Implementations
Sourceimpl DisplayTechnology
impl DisplayTechnology
Sourcepub fn from_nibble(nibble: u8) -> Self
pub fn from_nibble(nibble: u8) -> Self
Decodes the display technology from a 4-bit nibble (bits 7:4 of byte 0).