#[non_exhaustive]pub enum TransferPointEncoding {
Bits8,
Bits10,
Bits12,
}Expand description
Bit-depth encoding for transfer characteristic sample points, decoded from
the Transfer Characteristics Block (DisplayID 1.x 0x0E) byte 0 bits 7:6.
The same three encodings are used by the CEA-861 VESA Display Transfer
Characteristic Data Block (standard tag 0x05).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Bits8
8 bits per luminance point: one byte per sample, range 0–255.
Bits10
10 bits per luminance point: 5 bytes packed MSB-first per 4 samples, range 0–1023.
Bits12
12 bits per luminance point: 3 bytes packed MSB-first per 2 samples, range 0–4095.